@@ -100,7 +100,7 @@ class Domoticz(IPlugin):
 				log.msg("response   :  %s" % (jsonreq))
 				log.msg("*********************************************  : ")
 				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
-				total = range(len(jsonreq['result']))
+				total = len(jsonreq['result'])
 				log.msg(" total    :  %s" % (total))	
 				for xx in total:
 					log.msg(" jsonreq - idx   :  %s" % (xx(idx)))
